@@ -41,12 +41,13 @@ class AmazonSESMailer(BaseMailer):
                 'body': msg.html or msg.text,
                 'to_addresses': msg.to,
 
-                'cc_addresses': msg.cc,
-                'bcc_addresses': msg.bcc,
-                'reply_addresses': msg.reply_to,
+                'cc_addresses': msg.cc or None,
+                'bcc_addresses': msg.bcc or None,
+                'reply_addresses': msg.reply_to or None,
                 'format': 'html' if msg.html else 'text',
             }
             if self.return_path:
                 data['return_path'] = self.return_path
             logger.debug('Sending email from {0} to {1}'.format(msg.from_email, msg.to))
+            print data
             self.conn.send_email(**data)
